@@ -53,16 +53,19 @@ AboutDialog::AboutDialog( QWidget *parent)
     "</li>"
     "<li>Translation"
     "  <ul>"
-    "    <li>Spanish: <a href=\"http://ieee.udistrital.edu.co/aclibre\">"
-    "                 ACLibre (Academia y Conocimiento Libre)</a> and David Amian</li>"
-    "    <li>French: Marc Sert, Philippe Caillaud and Claude </li>"
-    "    <li>Italian: Giovanni Sora, Seyed Puria Nafisi Azizi </li>"
-    "    <li>Interlingua: Giovanni Sora</li>"
     "    <li>Brasilian: Amadeu Júnior</li>"
-    "    <li>Russian: Anton Olenev</li>"
-    "    <li>Simplified Chinese: Moligaloo</li>"
-    "    <li>Traditional Chinese: Wei-Lun Chao </li>"
+    "    <li>Chinese (simplified): Moligaloo</li>"
+    "    <li>Chinese (traditional): Wei-Lun Chao </li>"
+    "    <li>Croatian: Damir Brašnić </li>"
+    "    <li>Czech: Pavel Fric</li>"
+    "    <li>French: Marc Sert, Philippe Caillaud and Claude </li>"
+    "    <li>Greek: Yannis Kaskamanidis</li>"
+    "    <li>Interlingua: Giovanni Sora</li>"
+    "    <li>Italian: Giovanni Sora, Seyed Puria Nafisi Azizi </li>"
     "    <li>Japanese: Tsuren Tsuchiya</li>"
+    "    <li>Russian: Anton Olenev</li>"
+    "    <li>Spanish: <a href=\"http://ieee.udistrital.edu.co/aclibre\">" 
+    "                 ACLibre (Academia y Conocimiento Libre)</a> and David Amian</li>"
     "  </ul>"
     "</li>"
     "<li> Patches"
@@ -101,7 +104,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "</ul>"
     "</li>").arg( QDate::currentDate().year() ) );;
     credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
-    tabs->addTab (credits,"Credits");
+    tabs->addTab (credits, tr("Credits","Help->About vym dialog"));
 
     license=new AboutTextBrowser (parent);
     license->setText ( QString(
@@ -216,7 +219,7 @@ AboutDialog::AboutDialog( QWidget *parent)
 "<p align=\"center\">END OF TERMS AND CONDITIONS</p>").arg( QDate::currentDate().year() ) );
 
     credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
-    tabs->addTab (license,"License");
+    tabs->addTab (license, tr("License","Help->About vym dialog"));
 
     mainLayout->addWidget (tabs);
 
