@@ -231,7 +231,7 @@ void BranchObj::moveBy (QPointF p)
     moveBy (p.x(), p.y());
 }
 
-void BranchObj::positionBBox() // FIXME-2 consider dimensions of frame (thickness, geometry, padding...
+void BranchObj::positionBBox() // FIXME-3 consider dimensions of frame (thickness, geometry, padding...
 {
     QPointF ap=getAbsPos();
     bbox.moveTopLeft (ap);
@@ -276,7 +276,7 @@ void BranchObj::calcBBoxSize()
     // Floatimages 
     QPointF rp;
 
-    topPad=botPad=leftPad=rightPad=0;
+    topPad = botPad = leftPad = rightPad = 0;
     bool incV=((BranchItem*)treeItem)->getIncludeImagesVer();
     bool incH=((BranchItem*)treeItem)->getIncludeImagesHor();
     if (incH || incV)
@@ -291,8 +291,8 @@ void BranchObj::calcBBoxSize()
                 qreal y;
                 if (rp.y() > 0)
                 {
-                    y=rp.y() + fio->height()/2 - ornamentsBBox.height()/2;
-                    botPad=max(botPad, y);
+                    y = rp.y() + fio->height()/2 - ornamentsBBox.height()/2;
+                    botPad = max(botPad, y);
                 } else
                 {
                     y=-rp.y() + fio->height()/2 - ornamentsBBox.height()/2;
@@ -313,8 +313,8 @@ void BranchObj::calcBBoxSize()
                 }
 	    }	    
 	}   
-	h+=topPad+botPad;
-	w+=leftPad+rightPad;
+	h += topPad + botPad;
+	w += leftPad + rightPad;
     }
 
     // Frame thickness  
@@ -524,8 +524,9 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
     //    qDebug() <<"  parO="<<parObj;
         //qDebug() <<   "  bbox.tL="<<bboxTotal.topLeft();
         << "  useRelPos=" << useRelPos 
+        << " layoutHint= " << layoutHint
     //    qDebug() <<"absPos="<<absPos
-    //	<< "  relPos="<<relPos
+    	<< "  relPos="<<relPos
     //	<< "  parPos="<<pp
     //	<< "  bbox="<<bbox
     	<< "  orient="<<o<<" "<<orientation;
@@ -536,8 +537,7 @@ void BranchObj::alignRelativeTo (QPointF ref,bool alignSelf)
     //	<< "  th="<<th
         ;
     }
-*/
-
+   */
 
     setOrientation();
 
