@@ -5,6 +5,7 @@
 #include "branchitem.h"
 #include "frameobj.h"
 #include "settings.h"
+#include "vymmodel.h"
 
 extern Settings settings;
 extern QString vymName;
@@ -78,7 +79,7 @@ void BranchPropertyEditor::setItem (TreeItem *ti)
 
             // Frame
             FrameObj::FrameType t=branchObj->getFrameType();
-            if (t==FrameObj::NoFrame)   // FIXME-2 Check if all below depends on frame type???
+            if (t==FrameObj::NoFrame)   // FIXME-3 Check if all below depends on frame type???
             {
                 ui.frameTypeCombo->setCurrentIndex (0);
                 penColor=Qt::white;
@@ -155,7 +156,7 @@ void BranchPropertyEditor::setItem (TreeItem *ti)
         // Attributes
         attributeModel->removeRows(0, attributeModel->rowCount(), QModelIndex());
 
-        // FIXME-5 some samples for attribute testing
+        // some samples for attribute testing
         QStringList attrTypes=mapEditor->attributeTable()->getTypes();
         for (int i=0; i<attrTypes.count()-1;i++)
         {
