@@ -10,9 +10,9 @@
 
 //#include "attributedelegate.h"
 #include "branchobj.h"
-#include "vymmodel.h"
 
 class QAbstractItemModel;
+class VymModel;
 
 class BranchPropertyEditor:public QDialog
 {
