@@ -25,9 +25,13 @@ private slots:
     void colorButtonPressed();
     void colorChanged(QColor c);
     void setColorHeadingButtonPressed ();
-    void lineStyleChanged (int);
+    void lineStyleChanged( int );
+    void beginStyleChanged( int );
+    void endStyleChanged( int );
 
 private:
+    void emitChanged();
+
     Ui::EditXLinkDialog ui;
     bool delink;
     Link *link;
