@@ -146,7 +146,7 @@ bool ExportBase::execDialog()
             dia.setCaption(QObject::tr("Warning: Overwriting file"));
             dia.setText(QObject::tr("Exporting to %1 will overwrite the existing file:\n%2").arg(exportName).arg(fn));
             dia.setShowAgainName("/exports/overwrite/" + exportName);
-            if (!dia.exec()==QDialog::Accepted)
+            if (!(dia.exec()==QDialog::Accepted))
             {
                 cancelFlag=true;
                 return false;
@@ -172,11 +172,13 @@ void ExportBase::setLastCommand( const QString &s)
 void ExportBase::completeExport(QString args) 
 {
     QString command;
-    // Add at least filepath as argument
     if (args.isEmpty()) 
+        // Add at least filepath as argument. exportName is added anyway
         command = QString("export%1(\"%2\")").arg(exportName).arg(filePath);
+        // new syntax: command = QString("vym.currentMap().exportMap(\"%1\",\"%2\")").arg(exportName).arg(filePath);
     else
         command = QString("export%1(%2)").arg(exportName).arg(args);
+        // new syntax: command = QString("vym.currentMap().exportMap(\"%1\",%2)").arg(exportName).arg(args);
 
     settings.setLocalValue ( model->getFilePath(), "/export/last/exportPath", filePath);
     settings.setLocalValue ( model->getFilePath(), "/export/last/command", command);
@@ -232,14 +234,16 @@ void ExportAO::doExport()
     QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-        qWarning()<<"ExportAO::doExport couldn't open " + filePath;//FIXME-3 missing GUI warning
+        QMessageBox::critical (0, QObject::tr("Critical Export Error"), QObject::tr("Could not export as AO to %1").arg(filePath));
+        mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
         return;
     }
 
     settings.setLocalValue ( model->getFilePath(), "/export/last/command","exportAO");
     settings.setLocalValue ( model->getFilePath(), "/export/last/description","A&O report");
 
-    QTextStream ts( &file );    // use LANG decoding here...
+    QTextStream ts( &file );
+    ts.setCodec("UTF-8");
 
     // Main loop over all branches
     QString s;
@@ -376,10 +380,12 @@ void ExportASCII::doExport()
     QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-        qWarning ()<<"ExportASCII::doExport couldn't open "+filePath;
+        QMessageBox::critical (0, QObject::tr("Critical Export Error"), QObject::tr("Could not export as ASCII to %1").arg(filePath));
+        mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
         return;
     }
-    QTextStream ts( &file );    // use LANG decoding here...
+    QTextStream ts( &file );
+    ts.setCodec("UTF-8");
 
     // Main loop over all branches
     QString s;
@@ -504,10 +510,12 @@ void ExportCSV::doExport()
     QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-        qWarning ()<<"ExportBase::exportXML  couldn't open "+filePath;
+        QMessageBox::critical (0, QObject::tr("Critical Export Error"), QObject::tr("Could not export as CSV to %1").arg(filePath));
+        mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
         return;
     }
-    QTextStream ts( &file );    // use LANG decoding here...
+    QTextStream ts( &file );
+    ts.setCodec("UTF-8");
 
     // Write header
     ts << "\"Note\""  <<endl;
@@ -556,7 +564,7 @@ void ExportKDE4Bookmarks::doExport()
     dia.setShowAgainName("/exports/overwrite/KDE4Bookmarks");
     if (dia.exec()==QDialog::Accepted)
     {
-        model->exportXML(tmpDir.path(),false);
+        model->exportXML("",tmpDir.path(),false);
 
         XSLTProc p;
         p.setInputFile (tmpDir.path()+"/"+model->getMapName()+".xml");
@@ -586,7 +594,7 @@ void ExportFirefoxBookmarks::doExport()
     dia.setShowAgainName("/vym/warnings/overwriteImportBookmarks");
     if (dia.exec()==QDialog::Accepted)
     {
-        model->exportXML(tmpDir.path(),false);
+        model->exportXML("",tmpDir.path(),false);
 
         /*
     XSLTProc p;
@@ -632,32 +640,37 @@ QString ExportHTML::getBranchText(BranchItem *current)
 {
     if (current)
     {
-        bool vis=false;
+        bool vis = false;
         QRectF hr;
-        LinkableMapObj *lmo=current->getLMO();
+        LinkableMapObj *lmo = current->getLMO();
         if (lmo)
         {
-            hr=((BranchObj*)lmo)->getBBoxHeading();
-            vis=lmo->isVisibleObj();
+            hr = ((BranchObj*)lmo)->getBBoxHeading();
+            vis = lmo->isVisibleObj();
         }
         QString col;
-        QString id=model->getSelectString(current);
+        QString id = model->getSelectString(current);
         if (dia.useTextColor)
-            col=QString("style='color:%1'").arg(current->getHeadingColor().name());
-        QString s=QString("<span class='vym-branch-%1' %2 id='%3'>")
+            col = QString("style='color:%1'").arg(current->getHeadingColor().name());
+        QString s = QString("<span class='vym-branch-%1' %2 id='%3'>")
                 .arg(current->depth())
                 .arg(col)
                 .arg(id);
-        QString url=current->getURL();
-        QString heading=quotemeta(current->getHeadingPlain());
+        QString url = current->getURL();
+        QString heading = quotemeta(current->getHeadingPlain());
 
         // Task flags
         QString taskFlags;
         if (dia.useTaskFlags)
         {
-            Task *task=current->getTask();
+            Task *task = current->getTask();
             if (task)
-                taskFlags+=QString("<img src=\"flags/flag-%1.png\">").arg(task->getIconString());
+            {
+                QString taskName = task->getIconString();
+                taskFlags += QString("<img src=\"flags/flag-%1.png\" alt=\"%2\">")
+                    .arg(taskName)
+                    .arg(QObject::tr("Flag: %1","Alt tag in HTML export").arg(taskName));
+            }
         }
 
         // User flags
@@ -665,37 +678,63 @@ QString ExportHTML::getBranchText(BranchItem *current)
         if (dia.useUserFlags)
         {
             foreach (QString flag, current->activeStandardFlagNames())
-                userFlags+=QString("<img src=\"flags/flag-%1.png\">").arg(flag);
+                userFlags += QString("<img src=\"flags/flag-%1.png\" alt=\"%2\">")
+                    .arg(flag)
+                    .arg(QObject::tr("Flag: %1","Alt tag in HTML export").arg(flag));
         }
 
+        // Numbering
+        QString number;
+        if (dia.useNumbering) number = getSectionString(current) + " ";
+        
         // URL
         if (!url.isEmpty())
         {
-            s+=QString ("<a href=\"%1\"><img src=\"flags/flag-url-16x16.png\">%2</a>")
+            s += QString ("<a href=\"%1\">%2<img src=\"flags/flag-url.png\" alt=\"%3\"></a>")
                     .arg(url)
-                    .arg(taskFlags + heading + userFlags);
+                    .arg(number + taskFlags + heading + userFlags)
+                    .arg(QObject::tr("Flag: url","Alt tag in HTML export"));
 
-            QRectF fbox=current->getBBoxURLFlag ();
+            QRectF fbox = current->getBBoxURLFlag ();
             if (vis)
-                imageMap+=QString("  <area shape='rect' coords='%1,%2,%3,%4' href='%5'>\n")
-                        .arg(fbox.left()-offset.x())
-                        .arg(fbox.top()-offset.y())
-                        .arg(fbox.right()-offset.x())
-                        .arg(fbox.bottom()-offset.y())
-                        .arg(url);
+                imageMap += QString("  <area shape='rect' coords='%1,%2,%3,%4' href='%5' alt='%6'>\n")
+                        .arg(fbox.left()   - offset.x())
+                        .arg(fbox.top()    - offset.y())
+                        .arg(fbox.right()  - offset.x())
+                        .arg(fbox.bottom() - offset.y())
+                        .arg(url)
+                        .arg(QObject::tr("External link: %1","Alt tag in HTML export").arg(heading));
         } else
-            s+=taskFlags + heading + userFlags;
+            s += number + taskFlags + heading + userFlags;
 
-        s+="</span>";
+        s += "</span>";
 
         // Create imagemap
-        if (vis && dia.useImage)
-            imageMap+=QString("  <area shape='rect' coords='%1,%2,%3,%4' href='#%5'>\n")
-                    .arg(hr.left()-offset.x())
-                    .arg(hr.top()-offset.y())
-                    .arg(hr.right()-offset.x())
-                    .arg(hr.bottom()-offset.y())
-                    .arg(id);
+        if (vis && dia.includeMapImage)
+            imageMap += QString("  <area shape='rect' coords='%1,%2,%3,%4' href='#%5' alt='%6'>\n")
+                    .arg(hr.left()   - offset.x())
+                    .arg(hr.top()    - offset.y())
+                    .arg(hr.right()  - offset.x())
+                    .arg(hr.bottom() - offset.y())
+                    .arg(id)
+                    .arg(heading);
+
+        // Include images experimental
+        if (dia.includeImages)
+        {
+            int imageCount = current->imageCount();
+            ImageItem *image; 
+            QString imagePath;
+            for (int i=0; i< imageCount; i++)
+            {
+                image = current->getImageNum(i);
+                imagePath =  "image-" + image->getUuid().toString() + ".png";
+                image->save( dirPath + "/" + imagePath, "PNG");
+                s += "</br><img src=\"" + imagePath;
+                s += "\" alt=\"" + QObject::tr("Image: %1","Alt tag in HTML export").arg(image->getOriginalFilename());
+                s += "\"></br>";
+            }
+        }
 
         // Include note
         if (!current->isNoteEmpty())
@@ -748,12 +787,12 @@ QString ExportHTML::buildList (BranchItem *current)
 {
     QString r;
 
-    uint i=0;
-    uint visChilds=0;
+    uint i = 0;
+    uint visChilds = 0;
 
-    BranchItem *bi=current->getFirstBranch();
+    BranchItem *bi = current->getFirstBranch();
 
-    QString ind="\n" + indent(current->depth() + 1, false);
+    QString ind = "\n" + indent(current->depth() + 1, false);
 
     QString sectionBegin;
     QString sectionEnd;
@@ -763,45 +802,45 @@ QString ExportHTML::buildList (BranchItem *current)
     switch (current->depth() + 1)
     {
     case 0:
-        sectionBegin="";
-        sectionEnd="";
-        itemBegin="<h1>";
-        itemEnd="</h1>";
+        sectionBegin = "";
+        sectionEnd   = "";
+        itemBegin    = "<h1>";
+        itemEnd      = "</h1>";
         break;
     case 1:
-        sectionBegin="";
-        sectionEnd="";
-        itemBegin="<h2>";
-        itemEnd="</h2>";
+        sectionBegin = "";
+        sectionEnd   = "";
+        itemBegin    = "<h2>";
+        itemEnd      = "</h2>";
         break;
     default:
-        sectionBegin="<ul " + QString("class=\"vym-list-ul-%1\"").arg(current->depth() + 1)  +">";
-        sectionEnd="</ul>";
-        itemBegin="  <li>";
-        itemEnd="  </li>";
+        sectionBegin = "<ul " + QString("class=\"vym-list-ul-%1\"").arg(current->depth() + 1)  +">";
+        sectionEnd   = "</ul>";
+        itemBegin    = "  <li>";
+        itemEnd      = "  </li>";
         break;
     }
     
     if (bi && !bi->hasHiddenExportParent() && !bi->isHidden() )
     {
-        r+=ind + sectionBegin;
+        r += ind + sectionBegin;
         while (bi)
         {
             if (!bi->hasHiddenExportParent() && !bi->isHidden())
             {
                 visChilds++;
-                r+=ind + itemBegin;
-                r+=getBranchText (bi);
+                r += ind + itemBegin;
+                r += getBranchText (bi);
 
                 if (itemBegin.startsWith("<h") )
-                    r+=itemEnd + buildList (bi);
+                    r += itemEnd + buildList (bi);
                 else
-                    r+=buildList (bi) + itemEnd;
+                    r += buildList (bi) + itemEnd;
             }
             i++;
-            bi=current->getBranchNum(i);
+            bi = current->getBranchNum(i);
         }
-        r+=ind + sectionEnd;
+        r += ind + sectionEnd;
     }
 
     return r;
@@ -817,20 +856,20 @@ QString ExportHTML::createTOC()
     toc += "\n";
     toc += "</td></tr>\n";
     toc += "<tr><td>\n";
-    BranchItem *cur=NULL;
-    BranchItem *prev=NULL;
-    model->nextBranch(cur,prev);
+    BranchItem *cur  = NULL;
+    BranchItem *prev = NULL;
+    model->nextBranch(cur, prev);
     while (cur)
     {
         if (!cur->hasHiddenExportParent() && !cur->hasScrolledParent() )
         {
-            if (dia.useNumbering) number=getSectionString(cur);
-            toc +=QString("<div class=\"vym-toc-branch-%1\">").arg(cur->depth());
-            toc +=QString("<a href=\"#%1\"> %2 %3</a></br>\n")
+            if (dia.useNumbering) number = getSectionString(cur);
+            toc += QString("<div class=\"vym-toc-branch-%1\">").arg(cur->depth());
+            toc += QString("<a href=\"#%1\"> %2 %3</a></br>\n")
                     .arg(model->getSelectString(cur))
                     .arg(number)
                     .arg(quotemeta( cur->getHeadingPlain() ));
-            toc +="</div>";
+            toc += "</div>";
         }
         model->nextBranch(cur,prev);
     }
@@ -881,7 +920,7 @@ void ExportHTML::doExport(bool useDialog)
     if (dia.css_copy)
     {
         cssSrc=dia.getCssSrc();
-        cssDst=dia.getDir().absolutePath() + "/" + basename(dia.getCssDst());
+        cssDst=dirPath + "/" + basename(dia.getCssDst());
         if (cssSrc.isEmpty() )
         {
             QMessageBox::critical( 0,
@@ -909,18 +948,18 @@ void ExportHTML::doExport(bool useDialog)
         if (!dia.getDir().mkdir("flags"))
         {
             QMessageBox::critical( 0,
-                                   QObject:: tr( "Critical" ),
-                                   QObject::tr("Trying to create directory for flags:")+"\n\n"+
+                                   QObject::tr( "Critical" ),
+                                   QObject::tr("Trying to create directory for flags:") + "\n\n" +
                                    QObject::tr("Could not create %1").arg(flagsDst.absolutePath()));
             return;
         }
     }
 
-    QDir flagsSrc(flagsPath);   // FIXME-1 don't use flagsPath anymore, copy required flags directly from memory
-    if (!copyDir(flagsSrc,flagsDst,true))
+    QDir flagsSrc(flagsPath);   // FIXME-3 don't use flagsPath as source anymore, but copy required flags directly from memory
+    if (!copyDir(flagsSrc, flagsDst, true))
     {
         QMessageBox::critical( 0,
-                               QObject:: tr( "Critical" ),
+                               QObject::tr( "Critical" ),
                                QObject::tr("Could not copy %1 to %2").arg(flagsSrc.absolutePath()).arg(flagsDst.absolutePath()));
         return;
     }
@@ -931,35 +970,38 @@ void ExportHTML::doExport(bool useDialog)
     {
         QMessageBox::critical (0,
                                QObject::tr("Critical Export Error"),
-                               QObject::tr("Trying to save HTML file:")+"\n\n"+
+                               QObject::tr("Trying to save HTML file:") + "\n\n"+
                                QObject::tr("Could not write %1").arg(filePath));
         mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
         return;
     }
-    QTextStream ts( &file );    // use LANG decoding here...
-    //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
+    QTextStream ts( &file );
+    ts.setCodec("UTF-8");
 
     // Hide stuff during export
     model->setExportMode (true);
 
     // Write header
-    ts<<"<html>";
-    ts<<"\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"> ";
-    ts<<"\n<meta name=\"generator=\" content=\" vym - view your mind - " + vymHome + "\">";
-    ts<<"\n<meta name=\"author\" content=\"" + quotemeta(model->getAuthor()) + "\"> ";
-    ts<<"\n<meta name=\"description\" content=\"" + quotemeta(model->getComment()) + "\"> ";
-    ts<<"\n<link rel='stylesheet' id='css.stylesheet' href='"<<basename(cssDst)<<"' />\n";
+    ts << "<html>";
+    ts << "\n<meta http-equiv=\"content-type\" content=\"text/html; charset=UTF-8\"> ";
+    ts << "\n<meta name=\"generator=\" content=\" vym - view your mind - " + vymVersion + " - " + vymHome + "\">";
+    ts << "\n<meta name=\"author\" content=\"" + quotemeta(model->getAuthor()) + "\"> ";
+    ts << "\n<meta name=\"description\" content=\"" + quotemeta(model->getComment()) + "\"> ";
+    ts << "\n<link rel='stylesheet' id='css.stylesheet' href='" << basename(cssDst) << "' />\n";
     QString title=model->getTitle();
     if (title.isEmpty()) title=model->getMapName();
-    ts<<"\n<head><title>" + quotemeta(title) + "</title></head>";
-    ts<<"\n<body>\n";
+    ts << "\n<head><title>" + quotemeta(title) + "</title></head>";
+    ts << "\n<body>\n";
 
     // Include image
     // (be careful: this resets Export mode, so call before exporting branches)
-    if (dia.useImage)
+    if (dia.includeMapImage)
     {
-        ts<<"<center><img src=\""<<getMapName()<<".png\" usemap='#imagemap'></center>\n";
-        offset=model->exportImage (dirPath+"/"+getMapName()+".png",false,"PNG");
+        QString mapName = getMapName();
+        ts << "<center><img src=\"" << mapName << ".png\"";
+        ts << "alt=\"" << QObject::tr("Image of map: %1.vym","Alt tag in HTML export").arg(mapName) << "\"";
+        ts << " usemap='#imagemap'></center>\n";
+        offset = model->exportImage (dirPath + "/" + mapName + ".png", false, "PNG");
     }
 
     // Include table of contents
@@ -969,24 +1011,24 @@ void ExportHTML::doExport(bool useDialog)
     ts << buildList(model->getRootItem()) << "\n";
 
     // Imagemap
-    ts<<"<map name='imagemap'>\n"+imageMap+"</map>\n";
+    ts << "<map name='imagemap'>\n" + imageMap + "</map>\n";
 
     // Write footer
-    ts<<"<hr/>\n";
-    ts<<"<table class=\"vym-footer\">   \n\
+    ts << "<hr/>\n";
+    ts << "<table class=\"vym-footer\">   \n\
         <tr> \n\
-        <td class=\"vym-footerL\">"+filePath+"</td> \n\
-            <td class=\"vym-footerC\">"+model->getDate()+"</td> \n\
-            <td class=\"vym-footerR\"> <a href='" + vymHome + "'>vym "+vymVersion+"</a></td> \n\
+        <td class=\"vym-footerL\">" + filePath + "</td> \n\
+            <td class=\"vym-footerC\">" + model->getDate() + "</td> \n\
+            <td class=\"vym-footerR\"> <a href='" + vymHome + "'>vym " + vymVersion + "</a></td> \n\
             </tr> \n \
             </table>\n";
-            ts<<"</body></html>";
+            ts << "</body></html>";
     file.close();
 
     if (!dia.postscript.isEmpty())
     {
         VymProcess p;
-        p.runScript (dia.postscript,dirPath + "/" + filePath);
+        p.runScript (dia.postscript,dirPath + "/" + filePath);  
     }
 
     completeExport( QString("\"%1\",\"%2\"").arg(dirPath).arg(filePath));
@@ -998,7 +1040,7 @@ void ExportHTML::doExport(bool useDialog)
 ////////////////////////////////////////////////////////////////////////
 void ExportTaskjuggler::doExport() 
 {
-    model->exportXML(tmpDir.path(),false);
+    model->exportXML("",tmpDir.path(),false);
 
     XSLTProc p;
     p.setInputFile (tmpDir.path()+"/"+model->getMapName()+".xml");
@@ -1024,12 +1066,12 @@ void ExportOrgMode::doExport()
     QFile file (filePath);
     if ( !file.open( QIODevice::WriteOnly ) )
     {
-        QMessageBox::critical (0,QObject::tr("Critical Export Error"),QObject::tr("Could not write %1").arg(filePath));
+        QMessageBox::critical (0, QObject::tr("Critical Export Error"), QObject::tr("Could not export as OrgMode to %1").arg(filePath));
         mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
         return;
     }
-    QTextStream ts( &file );  // use LANG decoding here...
-    //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
+    QTextStream ts( &file );
+    ts.setCodec("UTF-8");
 
     // Main loop over all branches
     QString s;
@@ -1105,12 +1147,12 @@ void ExportLaTeX::doExport()
         QMessageBox::critical (
                     0,
                     QObject::tr("Critical Export Error"),
-                    QObject::tr("Could not write %1").arg(filePath));
+                    QObject::tr("Could not export as LaTeX to %1").arg(filePath));
         mainWindow->statusMessage(QString(QObject::tr("Export failed.")));
         return;
     }
-    QTextStream ts( &file );  // use LANG decoding here...
-    //FIXME-4 ts.setEncoding (QTextStream::UnicodeUTF8); // Force UTF8
+    QTextStream ts( &file );
+    ts.setCodec("UTF-8");
 
     // Read default section names
     QStringList sectionNames;
@@ -1191,7 +1233,7 @@ QString ExportOO::buildList (TreeItem *current)
                 r += quotemeta(bi->getHeadingPlain());
                 // If necessary, write note
                 if (! bi->isNoteEmpty())
-                    r += bi->getNoteOpenDoc();
+                    r += "<text:line-break/>" + bi->getNoteASCII();
                 r += "</text:p>";
                 r += buildList (bi);  // recursivly add deeper branches
                 r += "</text:list-item>\n";
@@ -1290,6 +1332,7 @@ void ExportOO::exportPresentation()
     }
 
     QTextStream t( &f );
+    t.setCodec("UTF-8");
     t << content;
     f.close();
 
