@@ -15,6 +15,10 @@
     #include <windows.h>
 #endif
 
+#if defined(Q_OS_MACX)
+    #include "unistd.h"
+#endif
+
 using namespace File;
 
 extern QString zipToolPath;
@@ -151,7 +155,7 @@ void removeDir(QDir d)
     // This check should_ not be necessary, but proved to be useful ;-)
     if (!isInTmpDir(d.path()))
     {
-        qWarning ()<<"file.cpp::removeDir should remove "+d.path()+" - aborted.";
+        qWarning ()<<"file.cpp::removeDir should remove " + d.path() + " - aborted.";
         return;
     }
 
@@ -186,8 +190,10 @@ void removeDir(QDir d)
         QFile (fi.filePath()).remove();
     }
 
-    if (!d.rmdir(d.path()))
-        qWarning ()<<"removeDir("+d.path()+") failed!";
+    QString dirName = d.dirName();
+    d.cdUp();
+    if (!d.rmdir(dirName))
+        qWarning ()<< "removeDir(" + dirName + ") failed!";
 }	
 
 bool copyDir (QDir src, QDir dst, const bool &override)   
@@ -235,6 +241,7 @@ void makeSubDirs (const QString &s)
 
 ErrorCode zipDir ( QDir zipInputDir, QString zipName)
 {
+    zipName = QDir::toNativeSeparators(zipName);
     ErrorCode err = Success;
 
     QString symLinkTarget;
@@ -246,13 +253,13 @@ ErrorCode zipDir ( QDir zipInputDir, QString zipName)
     {
         symLinkTarget = file.symLinkTarget();
         newName = zipName + ".tmp";
-        int n=0;
-        while (!file.rename (newName) && n<5)
+        int n = 0;
+        while (!file.rename (newName) && n < 5)
         {
             newName = newName + QString().setNum(n);
             n++;
         }
-        if (n>=5)
+        if (n >= 5)
         {
             QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
                                    QObject::tr("Couldn't move existing file out of the way before saving."));
@@ -262,11 +269,13 @@ ErrorCode zipDir ( QDir zipInputDir, QString zipName)
 
     // zip the temporary directory
     VymProcess *zipProc=new VymProcess ();
-    zipProc->setWorkingDirectory (zipInputDir.path());
+    QStringList args;
 
 #if defined(Q_OS_WIN32)
-    QByteArray result;
-    zipProc->start("cmd");
+    zipProc->setWorkingDirectory (QDir::toNativeSeparators(zipInputDir.path() + "\\") );    
+    args << "a" << zipName << "-tzip" << "-scsUTF-8"  << "*";
+    zipProc->start(zipToolPath, args);
+ 
     if (!zipProc->waitForStarted())
     {
         QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
@@ -274,17 +283,41 @@ ErrorCode zipDir ( QDir zipInputDir, QString zipName)
         err=Aborted;
 
     }
-    zipProc->write(QString("\"%1\" a \"%2\" -tzip -r %3\\*\n").arg(zipToolPath).arg(zipName).arg(zipInputDir.path()).toUtf8());
-    zipProc->closeWriteChannel();   //done Writing
-
     while(zipProc->state()!=QProcess::NotRunning){
         zipProc->waitForReadyRead();
         result = zipProc->readAll();
-        //vout << result << flush;
     }
-    //vout << zipProc->getStdout()<<flush;
+    
+    if (!zipProc->waitForStarted() )
+    {
+        // zip could not be started
+        QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
+                               QObject::tr("Couldn't start zip to compress data."));
+        err=Aborted;
+    } else
+    {
+        // zip could be started
+        zipProc->waitForFinished();
+        if (zipProc->exitStatus()!=QProcess::NormalExit )
+        {
+            QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
+                                   QObject::tr("zip didn't exit normally")+
+                                   "\n" + zipProc->getErrout());
+            err=Aborted;
+        } else
+        {
+            if (zipProc->exitCode()>0)
+            {
+                QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
+                                       QString("zip exit code:  %1").arg(zipProc->exitCode() )+
+                                       "\n" + zipProc->getErrout() );
+                err=Aborted;
+            }
+        }
+    }
+    // qDebug() <<"Output: " << zipProc->getStdout()<<flush;   
 #else
-    QStringList args;
+    zipProc->setWorkingDirectory (QDir::toNativeSeparators(zipInputDir.path() ));  
     args <<"-r";
     args <<zipName;
     args <<".";
@@ -351,10 +384,10 @@ ErrorCode zipDir ( QDir zipInputDir, QString zipName)
             }
         }
 
-	// Remove temporary file
+    // Remove temporary file
 	if (!newName.isEmpty()  && !file.remove() )
 	    QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
-	       QObject::tr("Saved %1, but couldn't remove %2").arg(zipName).arg(newName));
+           QObject::tr("Saved %1, but couldn't remove %2").arg(zipName).arg(newName));
     }
 
     return err;	
@@ -364,41 +397,40 @@ File::ErrorCode unzipDir ( QDir zipOutputDir, QString zipName)
 {
     ErrorCode err=Success;
 
-    // Try to unzip file
-
-    VymProcess *zipProc=new VymProcess ();
-    zipProc->setWorkingDirectory (zipOutputDir.path());
+    VymProcess *zipProc = new VymProcess ();
+    QStringList args;
 
 #if defined(Q_OS_WIN32)
-    QByteArray result;
-    zipProc->start("cmd");
+    zipProc->setWorkingDirectory (QDir::toNativeSeparators(zipOutputDir.path() + "\\") );
+    args << "-o" + zipOutputDir.path() << "x" << zipName.toUtf8() << "-scsUTF-8";
+    zipProc->start(zipToolPath, args);
+
     if (!zipProc->waitForStarted())
     {
         QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
                                QObject::tr("Couldn't start tool to decompress data."));
         err=Aborted;
     }
-    zipProc->write(QString("\"%1\" -o%2 x \"%3\"\n").arg(zipToolPath).arg(zipOutputDir.path()).arg(zipName).toUtf8());
-    zipProc->closeWriteChannel();   //done Writing
 
     while(zipProc->state()!=QProcess::NotRunning){
         zipProc->waitForReadyRead();
         result = zipProc->readAll();
-        //vout << result << flush;
+        //qDebug() << result << flush;
     }
-    //vout << zipProc->getStdout()<<flush;
+    //qDebug() << zipProc->getStdout()<<flush;
 #else
-    QStringList args;
+    zipProc->setWorkingDirectory (QDir::toNativeSeparators(zipOutputDir.path()));
     args << "-o";   // overwrite existing files!
     args << zipName ;
     args << "-d";
     args << zipOutputDir.path();
 
     zipProc->start ("unzip",args);
+#endif
     if (!zipProc->waitForStarted() )
     {
         QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
-                               QObject::tr("Couldn't start unzip to decompress data."));
+                               QObject::tr("Couldn't start %1 to decompress data.").arg(zipToolPath));
         err=Aborted;
 
 
@@ -408,7 +440,7 @@ File::ErrorCode unzipDir ( QDir zipOutputDir, QString zipName)
         if (zipProc->exitStatus()!=QProcess::NormalExit )
         {
             QMessageBox::critical( 0,QObject::tr( "Critical Error" ),
-                                   QObject::tr("unzip didn't exit normally") +
+                                   QObject::tr("%1 didn't exit normally").arg(zipToolPath) +
                                    zipProc->getErrout() );
             err=Aborted;
         } else
@@ -421,14 +453,13 @@ File::ErrorCode unzipDir ( QDir zipOutputDir, QString zipName)
                 else
                 {
                     QMessageBox::critical( 0, QObject::tr( "Critical Error" ),
-                                           QString("unzip exit code:  %1").arg(zipProc->exitCode() ) +
+                                           QString("%1 exit code:  %2").arg(zipToolPath).arg(zipProc->exitCode() ) +
                                            zipProc->getErrout() );
                     err=Aborted;
                 }
             }
         }
     }
-#endif
     return err;
 }
 
