@@ -4,12 +4,13 @@
 extern Settings settings;
 extern QString vymName;
 
-HeadingEditor::HeadingEditor(QString scope):TextEditor(scope)
+HeadingEditor::HeadingEditor(QString scope):TextEditor()
 {
-    setWindowTitle (vymName +" - " +tr ("Heading Editor","Window caption"));
+    editorName = tr("Note Editor","Name of editor shown as window title");
+    setWindowTitle("");
 
     // Load Settings
-    init ("shortcutScope");
+    init (scope);
 }
 
 HeadingEditor::~HeadingEditor() {}
