@@ -7,8 +7,7 @@
 
 class HeadingObj:public MapObj {
 public:
-    HeadingObj();
-    HeadingObj(QGraphicsScene*);
+    HeadingObj(QGraphicsItem*);
     virtual ~HeadingObj();
     virtual void init();
     virtual void copy(HeadingObj*);
@@ -19,6 +18,13 @@ public:
 private:
 //    QGraphicsSimpleTextItem* newLine(QString);		// generate new textline
     QGraphicsTextItem* newLine(QString);		// generate new textline
+public:    
+    virtual void setTransformOriginPoint (const QPointF &);
+    virtual void setRotation (qreal const &a);
+    virtual qreal getRotation();
+private:
+    qreal angle;    
+
 public:    
     virtual void setText(QString);
     virtual QString text();
@@ -34,8 +40,7 @@ public:
 protected:
     QString heading;
     int textwidth;								// width for formatting text
-//    QList <QGraphicsSimpleTextItem*> textline;	// a part of e.g. the parabel
-    QList <QGraphicsTextItem*> textline;	// a part of e.g. the parabel
+    QList <QGraphicsTextItem*> textline;
     QColor color;
     QFont font;
 };
