@@ -46,8 +46,9 @@ QString vymBuildDate;
 QString vymCodeName;
 QString vymInstanceName;
 QString vymPlatform;
+QString localeName;
 
-QTextStream vout(stdout);        // vymout - Testing for now
+QTextStream vout(stdout);        // vymout - Testing for now. Flush after writing...
 
 bool bugzillaClientAvailable;	// openSUSE specific currently
 
@@ -120,7 +121,8 @@ void msgHandler (QtMsgType type, const QMessageLogContext &context, const QStrin
     case QtFatalMsg:
         fprintf(stderr, "Fatal: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
         fatalCount++;
-        //abort();
+    default:
+        fprintf(stderr, "Info: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
     }
 }
 
@@ -137,6 +139,9 @@ int main(int argc, char* argv[])
     // Install our own handler for messages
     qInstallMessageHandler(msgHandler);
 
+    // Testing for now
+    vout.setCodec("UTF-8");
+
     // Reading and initializing options commandline options
     options.add ("batch", Option::Switch, "b", "batch");
     options.add ("commands", Option::Switch, "c", "commands");
@@ -144,6 +149,7 @@ int main(int argc, char* argv[])
     options.add ("debug", Option::Switch, "d", "debug");
     options.add ("help", Option::Switch, "h", "help");
     options.add ("local", Option::Switch, "l", "local");
+    options.add ("locale", Option::String, "locale", "locale");
     options.add ("name", Option::String, "n", "name");
     options.add ("quit", Option::Switch, "q", "quit");
     options.add ("run", Option::String, "r", "run");
@@ -166,12 +172,13 @@ int main(int argc, char* argv[])
                 "-d           debug       Show debugging output\n"
                 "-h           help        Show this help text\n"
                 "-l           local       Run with ressources in current directory\n"
+                "--locale     locale      Override system locale setting to select language\n"
                 "-n  STRING   name        Set name of instance for DBus access\n"
                 "-q           quit        Quit immediatly after start for benchmarking\n"
                 "-r  FILE     run         Run script\n"
                 "-R           restore     Restore last session\n"
                 "-s           shortcuts   Show Keyboard shortcuts on start\n"
-                "-sl          LaTeX       Show Keyboard shortcuts in LaTeX format on start\n"
+                "--sl         LaTeX       Show Keyboard shortcuts in LaTeX format on start\n"
                 "-t           testmode    Test mode, e.g. no autosave and changing of its setting\n"
                 "-v           version     Show vym version\n"
                 );
@@ -260,8 +267,10 @@ int main(int argc, char* argv[])
             // ok, let's find my way on my own
         {
 #if defined (Q_OS_MACX)
-            vymBaseDir.setPath(vymBaseDir.currentPath() +"/vym.app/Contents/Resources");
-
+            // Executable is in vym.app/Contents/MacOS, so go up first:
+            vymBaseDir = QCoreApplication::applicationDirPath();
+            vymBaseDir.cdUp();
+            vymBaseDir.cd("Resources");
 #elif defined (Q_OS_WIN32)
             QString basePath;
 
@@ -303,29 +312,14 @@ int main(int argc, char* argv[])
 #endif
         }
 
+    // Platform specific settings
+    vymPlatform = QSysInfo::prettyProductName();
+
 #if defined(Q_OS_MACX)
-    vymPlatform = "Mac";
 #elif defined(Q_OS_WIN32)
-    vymPlatform = "Win32";
     zipToolPath = settings.value("/system/zipToolPath", "c:\\Program Files\\7-Zip\\7z.exe").toString();
 #elif defined(Q_OS_LINUX)
-    QFile f("/etc/os-release");
-    QString flavour="Unknown";
-    if (f.exists())
-    {
-        QString s;
-        bool ok = loadStringFromDisk( f.fileName(), s);
-        if (ok)
-        {
-            QRegExp rx("PRETTY_NAME=.*\"(.*)\"");
-            rx.setMinimal(true);
-            int pos = rx.indexIn(s);
-            if (pos > -1) flavour = rx.cap(1);
-        }
-    }
-    vymPlatform = QString ("Linux (%1)").arg(flavour);
 #else
-    vymPlatform = "Unknown";
 #endif
     iconPath=vymBaseDir.path()+"/icons/";
     flagsPath=vymBaseDir.path()+"/flags/";
@@ -348,10 +342,43 @@ int main(int argc, char* argv[])
     }
 
     // Initialize translations
-    QTranslator translator (0);
-    //translator.load( QString("vym_")+QTextCodec::locale(), vymBaseDir.path() + "/lang");
-    translator.load( QString("vym_")+QLocale().name(), vymBaseDir.path() + "/lang");
-    app.installTranslator( &translator );
+    if (options.isOn ("locale"))
+    {
+        localeName = options.getArg ("locale");
+        if (debug) qDebug() << "Main:  using option for locale";
+    }
+    else
+    {
+#if defined(Q_OS_LINUX)
+        if (debug) qDebug() << "Main:  (OS Linux)   using $LANG for locale";
+        localeName = QProcessEnvironment::systemEnvironment().value("LANG","en");
+#else
+        if (debug) qDebug() << "Main:  (OS other)   using  QLocale::system().uiLanguages(  using for locale";
+        localeName = QLocale::system().uiLanguages().first();
+
+        if (localeName.contains("-"))
+        {
+            if (debug) qDebug() << "Main:  Replacing '-' with '_' in locale";
+            localeName.replace( "-", "_");
+        }
+#endif
+    }
+    
+    if (debug) 
+    {
+        qDebug() << "Main:     localName: " << localeName;
+        qDebug() << "Main:  translations: " << localeName, vymBaseDir.path() + "/lang";
+        qDebug() << "Main:   uiLanguages: " << QLocale::system().uiLanguages();
+        qDebug() << "Main:          LANG: " << QProcessEnvironment::systemEnvironment().value("LANG","foobar");
+    }
+  
+    QTranslator vymTranslator;
+    if (!vymTranslator.load( QString("vym.%1").arg( localeName ), vymBaseDir.path() + "/lang") )
+        QMessageBox::warning( 0, QObject::tr( "Warning" ),
+                               QString("Couldn't load translations for locale \"%1\" in\n%2")
+                               .arg(localeName)
+                               .arg(vymBaseDir.path() + "/lang") );
+    app.installTranslator( &vymTranslator );
 
     // Initializing the master rows of flags
     systemFlagsMaster=new FlagRow;
@@ -360,14 +387,14 @@ int main(int argc, char* argv[])
     standardFlagsMaster->setName ("standardFlagsMaster");
 
     // Initialize editors
-    noteEditor = new NoteEditor(QObject::tr("Note Editor","Shortcut group"));
+    noteEditor = new NoteEditor("noteeditor");
     noteEditor->setWindowIcon (QPixmap (":/vym-editor.png"));
-    headingEditor = new HeadingEditor(QObject::tr("Heading Editor","Shortcut group"));
+    headingEditor = new HeadingEditor("headingeditor");
 
     // Check if there is a BugzillaClient
     QFileInfo fi(vymBaseDir.path()+"/scripts/BugzillaClient.pm");
     //bugzillaClientAvailable=fi.exists();
-    bugzillaClientAvailable=true;   //FIXME-2 add real check again
+    bugzillaClientAvailable=true;   //FIXME-3 add real check again
 
     // Initialize mainwindow
 #if defined(Q_OS_WIN32)
@@ -469,6 +496,9 @@ int main(int argc, char* argv[])
 
     app.exec();
 
+    // Cleanup
+    delete noteEditor;
+
     int s = warningCount + criticalCount + fatalCount;
     if ( s > 0 ) 
         qDebug() << "vym exiting with:\n" << 
