@@ -51,6 +51,10 @@ protected:
 
 private:
     void setupAPI();
+
+    /*! Helper method to clone actions later in MapEditor */
+    void cloneActionMapEditor( QAction *a, QKeySequence ks);
+
     void setupFileActions();
     void setupEditActions();
     void setupSelectActions();
@@ -82,6 +86,7 @@ public:
     VymModel* getModel(uint) const;
     void gotoModel (VymModel *m);
     int modelCount();
+    void updateTabName(VymModel *vm);
     
 private slots:
     void editorChanged();
@@ -100,9 +105,8 @@ private slots:
 public slots:	
     void fileSave(VymModel*);	// autosave from MapEditor
 private slots:	
-    void fileSaveAs(const SaveMode &);
     void fileSaveAs();
-    void fileImportKDE4Bookmarks();
+    void fileSaveAs(const SaveMode &);
     void fileImportFirefoxBookmarks();
     void fileImportFreemind();
     void fileImportMM();
@@ -118,7 +122,6 @@ private slots:
     void fileExportCSV();
     void fileExportOrgMode();
     void fileExportLaTeX();
-    void fileExportKDE4Bookmarks();
     void fileExportTaskjuggler();
     void fileExportImpress();
     void fileExportLast();
@@ -169,7 +172,7 @@ private slots:
     void editCycleTaskStatus();
     void editTaskSleepN();
     void editAddTimestamp();
-    void editMapInfo();
+    void editMapProperties();
     void editMoveUp();	
     void editMoveDown();    
     void editDetach();	
@@ -204,6 +207,7 @@ private slots:
 
 private slots:    
     void editToggleTarget();
+    bool initTargetsMenu( VymModel *model, QMenu *menu);
     void editGoToTarget();
     void editMoveToTarget();
     void editSelectPrevious();
@@ -258,7 +262,9 @@ public:
 
 public slots:
     void settingsAutosaveTime();
-    void settingsTaskShowParentsLevel();
+    void settingsDefaultMapAuthor();
+    void settingsShowParentsLevelTasks();
+    void settingsShowParentsLevelFindResults();
     void settingsToggleAutoLayout();
     void settingsToggleWriteBackupFile();
     void settingsToggleAnimation();
@@ -286,6 +292,7 @@ public slots:
     void selectInNoteEditor (QString s, int i);
     void setFocusMapEditor();
     void changeSelection (VymModel *model,const QItemSelection &newSel, const QItemSelection &delSel);
+    void updateDockWidgetTitles(VymModel *model);
 
     void updateActions();
     ModMode getModMode();
@@ -313,19 +320,19 @@ private slots:
     void helpDoc();
     void helpDemo();
     void helpShortcuts();
+    void debugInfo();
     void helpAbout();
     void helpAboutQT();
 
     void callMacro ();
-    void downloadReleaseNotesFinished(bool interactive=false);
-    void downloadReleaseNotesFinishedInt();
+    void downloadReleaseNotesFinished();
 
 public slots:
     void checkReleaseNotes();
-    bool downloadsEnabled(bool interactive=false);
-    void downloadUpdatesFinished(bool interactive=false);
+    bool downloadsEnabled(bool userTriggered = false);
+    void downloadUpdatesFinished(bool userTriggered = false);
     void downloadUpdatesFinishedInt();
-    void downloadUpdates(bool interactive);
+    void downloadUpdates(bool userTriggered);
     void checkUpdates();
 
 private:
@@ -346,7 +353,13 @@ private:
 
     BranchPropertyEditor *branchPropertyEditor;
 
-    QList <QAction*> actionListMap;
+public:
+    QList <QAction*> mapEditorActions;      //! allows mapEditor to clone actions and shortcuts
+    QList <QAction*> taskEditorActions;     //! allows taskEditor to clone actions and shortcuts
+private:
+    QList <QAction*> restrictedMapActions;  //! Actions reqire map and write access
+    QList <QAction*> unrestrictedMapActions;//! Actions require map, but work also in readonly, e.g. print, copy
+    QList <QAction*> actionListFiles;       //! File related actions, e.g. load, save, restore session
     QList <QAction*> actionListBranches;
     QList <QAction*> actionListItems;
 
@@ -379,6 +392,7 @@ private:
     QAction* actionFileRestoreSession;
     QAction* actionFileSave;
     QAction* actionFilePrint;
+    QAction* actionMapProperties;
     QAction* actionFileExportLast;
     QAction* actionUndo;
     QAction* actionRedo;
@@ -511,7 +525,8 @@ private:
     QAction* actionSettingsUseHideExport;
     QAction* actionSettingsToggleAutosave;
     QAction* actionSettingsAutosaveTime;
-    QAction* actionSettingsTaskShowParentsLevel;
+    QAction* actionSettingsShowParentsLevelTasks;
+    QAction* actionSettingsShowParentsLevelFindResults;
     QAction* actionSettingsToggleAutoLayout;
     QAction* actionSettingsWriteBackupFile;
     QAction* actionSettingsToggleDownloads;
