@@ -1,7 +1,6 @@
+
+#include <QDir>
 #include <stdint.h>
-#include <string.h>
-#include <errno.h>
-#include <io.h>
 #ifndef _WIN32
 #include <sys/time.h>
 
@@ -15,11 +14,10 @@ pid_t getpid (void);
 #include <direct.h>
 #endif
 
-char *
-mkdtemp(char *tmpl)
-{
-    // Implementation based on GLIBC implementation.
 
+QString
+mkdtemp(QString tmpl)
+{
     static const char letters[] =
         "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
 
@@ -27,17 +25,11 @@ mkdtemp(char *tmpl)
 
     const unsigned int ATTEMPTS_MIN = (62 * 62 * 62);
 
-    int save_errno = errno;
-
-    size_t len = strlen(tmpl);
-    if (len < 6 || strcmp(&tmpl[len - 6], "XXXXXX"))
+    if (tmpl.length() < 6 || !tmpl.endsWith("XXXXXX"))
     {
-        errno = EINVAL;
-        return NULL;
+        return QString();
     }
 
-    char *XXXXXX = &tmpl[len - 6];
-
     uint64_t random_time_bits = time(NULL);
 
     value += (random_time_bits ^ getpid());
@@ -46,29 +38,26 @@ mkdtemp(char *tmpl)
     for (count = 0; count < ATTEMPTS_MIN; value += 7777, ++count)
     {
         uint64_t v = value;
+        QString XXXXXX;
+        XXXXXX.append(letters[v % 62]);
+        v /= 62;
+        XXXXXX.append(letters[v % 62]);
+        v /= 62;
+        XXXXXX.append(letters[v % 62]);
+        v /= 62;
+        XXXXXX.append(letters[v % 62]);
+        v /= 62;
+        XXXXXX.append(letters[v % 62]);
+        v /= 62;
+        XXXXXX.append(letters[v % 62]);
 
-        XXXXXX[0] = letters[v % 62];
-        v /= 62;
-        XXXXXX[1] = letters[v % 62];
-        v /= 62;
-        XXXXXX[2] = letters[v % 62];
-        v /= 62;
-        XXXXXX[3] = letters[v % 62];
-        v /= 62;
-        XXXXXX[4] = letters[v % 62];
-        v /= 62;
-        XXXXXX[5] = letters[v % 62];
-
-	if (mkdir(tmpl) == 0)
-        {
-            errno = save_errno;
-	    return tmpl;
+        tmpl.replace(tmpl.length()-6,6,XXXXXX);
+        QDir dir;
+        if (dir.exists(tmpl))
+            continue;
+        if (dir.mkpath(tmpl)){
+            return tmpl;
         }
-
-	if (errno != EEXIST)
-	    return NULL;
     }
-
-    errno = EEXIST;
-    return NULL;
+    return QString();
 }
