@@ -8,14 +8,15 @@
 extern Settings settings;
 extern QString vymName;
 
-NoteEditor::NoteEditor(QString scope):TextEditor(scope)
+NoteEditor::NoteEditor(QString scope):TextEditor()
 {
-    setWindowTitle (vymName +" - " +tr ("Note Editor","Window caption"));
+    editorName = tr("Note Editor","Name of editor shown as window title");
+    setWindowTitle("");
 
     menuBar()->show();
 
     // Load Settings
-    init(shortcutScope);
+    init(scope);
 }
 
 NoteEditor::~NoteEditor() {}
