@@ -4,16 +4,16 @@
 
 #include "texteditor.h"
 
-class NoteObj;
+class VymNote;
 
 class NoteEditor : public TextEditor {
     Q_OBJECT
 public:
-    NoteEditor();
+    NoteEditor(QString scope);
     ~NoteEditor();
 
-    NoteObj getNoteObj();
-    void setNote(const NoteObj &note);
+    VymNote getNote();
+    void setNote(const VymNote &note);
 };
 
 #endif
