@@ -98,6 +98,7 @@ void ScriptEditor::saveFile()
     }
 
     QTextStream t( &f );
+    t.setCodec("UTF-8");
     t << ui.editor->toPlainText();
     f.close();
 }
@@ -196,7 +197,8 @@ void ScriptEditor::openClicked()
 	}   
 
 	QTextStream ts( &f );
-	ui.editor->setText( ts.readAll() );
+    ts.setCodec("UTF-8");
+    ui.editor->setText( ts.readAll() );
 	f.close();
 	lastMapDir.setPath(fn.left(fn.lastIndexOf ("/")) );
     }
