@@ -30,14 +30,16 @@ void ShowTextDialog::setHtml (const QString &s)
 
 void ShowTextDialog::useFixedFont (bool useFixedFont)
 {
+    QFont font;
     if (useFixedFont) 
-    {
-        QFont fixedFont;
-        fixedFont.fromString (settings.value(
+        font.fromString (settings.value(
                     "/satellite/noteeditor/fonts/fixedFont",
-                    "Courier,10,-1,5,48,0,0,0,1,0").toString() 
-                );
-    }
+                    "Courier,10,-1,5,48,0,0,0,1,0").toString() );
+     else
+        font.fromString (settings.value(
+                    "/satellite/noteeditor/fonts/varFont",
+                    "DejaVu Sans Mono,12,-1,0,50,0,0,0,0,0").toString() );
+     ui.textBrowser->setFont( font );
 }
 
 
