@@ -13,7 +13,6 @@ void TaskFilterModel::setFilter (bool b)
 }
 
 void TaskFilterModel::setMapFilter (const QString &s)	
-//FIXME-2 changing mapname does not retrigger filtering
 {
     mapFilter = s;
 }
@@ -23,14 +22,19 @@ void TaskFilterModel::setFilterNew (bool b)
     filterNew = b;
 }
 
+void TaskFilterModel::setFilterFlags (bool b)
+{
+    filterFlags = b;
+}
 bool TaskFilterModel::filterAcceptsRow(int sourceRow, 
          const QModelIndex &sourceParent) const
 {
     QModelIndex ix = sourceModel()->index(sourceRow, 0, sourceParent);
 
     // Filter by mapname
-    if ( !mapFilter.isEmpty() && (taskModel->getTask(ix)->getMapName() != mapFilter ) ) 
-        //FIXME-2 new (unnamed) map does not filter, but shows tasks from all maps
+    QString mapname = taskModel->getTask(ix)->getMapName();
+    if (mapname.isEmpty()) mapname = "justSomePseudoMapNameForFiltering";
+    if ( !mapFilter.isEmpty() && mapname != mapFilter )
         return false;
 
     // Filter new tasks
@@ -40,6 +44,11 @@ bool TaskFilterModel::filterAcceptsRow(int sourceRow,
     // Filter active tasks
     if (useFilter && ((taskModel->getTask(ix)->getDaysSleep() > 0) || (taskModel->getTask(ix)->getStatus() == Task::Finished) ) )
         return false;
+
+    // Filter flags  // FIXME-1 currently only "arrow-up"
+    if (filterFlags && !taskModel->getTask(ix)->getBranch()->hasActiveStandardFlag("arrow-up") )
+        return false;
+
     return true;
 }
 
