@@ -9,12 +9,14 @@ public:
     void setFilter (bool b);
     void setFilterNew (bool b);
     void setMapFilter (const QString &s);
+    void setFilterFlags (bool b);
 protected:    
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
 private:
     bool useFilter;
     QString mapFilter;
     bool filterNew;
+    bool filterFlags;
 };
 
 #endif
