@@ -69,30 +69,23 @@ QVariant TaskModel::data(const QModelIndex &index, int role) const
         else if (index.column() == 1)
             return t->getStatusString() + " - " +t->getAwakeString();
         else if (index.column() == 2)
-	    return t->getAgeCreation();
+            return t->getAgeCreation();
         else if (index.column() == 3)
-	    return t->getAgeModified();
+            return t->getAgeModified();
         else if (index.column() == 4)
-	    return t->getDaysSleep();
+            return t->getDaysSleep();
         else if (index.column() == 5)
-	    return bi->getModel()->getMapName();
+        {
+            QString s = bi->getModel()->getMapName();
+            if (s.isEmpty() )
+                return "-";    
+            else
+                return bi->getModel()->getMapName();
+        }
         else if (index.column() == 6)
         {
             BranchItem *bi = tasks.at(index.row())->getBranch();
-            QString s;
-            if (bi)
-                s = bi->getHeadingPlain();
-            else
-                qDebug()<<"bi == NULL";
-
-            int l = showParentsLevel;
-            while ( l > 0 && bi->depth() >0 )
-            {
-                bi = bi->parentBranch();
-                if (bi) s = bi->getHeadingPlain() + " -> " + s;
-                l--;
-            }
-            return s;
+            return bi->getHeadingPlainWithParents( showParentsLevel );
         }
     } else if (role == Qt::DecorationRole && index.column() == 1)
     {
@@ -280,11 +273,19 @@ void TaskModel::recalcPriorities()
 	}
 
 	// Color (importance)
-	QColor c=bi->getHeadingColor();
-	if (c==QColor ("#00aa7f") ) p-=20;
-	if (c==QColor ("#005500") ) p-=40;
-	if (c==QColor ("#d95100") ) p-=60;
-	if (c==QColor ("#ff0000") ) p-=80;
+	QColor c = bi->getHeadingColor();
+
+        // light blueish green
+	if (c == QColor ("#00aa7f") ) p -= 20;
+
+        // green (e.g. from vym < 2.6.3 with #005500)
+	if (c.red() == 0 && c.blue() == 0 && c.green() < 160) p -= 40;
+
+        // orange
+	if (c == QColor ("#d95100") ) p -= 60;
+
+        // red
+	if (c == QColor ("#ff0000") ) p -= 80;
 
 	// Flags
 	if (bi->hasActiveStandardFlag ("stopsign") ) p-=800;
@@ -293,6 +294,9 @@ void TaskModel::recalcPriorities()
 	p-=t->getAgeModified();
 	p-=t->getAgeCreation() * 1.0 / 365 * 80; // After a year, this is as important as "red"
 
+        // Position in subtree
+        p += bi->num();
+
 	t->setPriority (p);
 	if (p<minPrio) minPrio=p;
     }
