@@ -8,7 +8,8 @@ TESTMAP=$VYMTESTDIR/testmap.vym
 
 cp $DEFAULTMAP $TESTMAP
 
-vym  -l -t -n test $TESTMAP -geometry 768x576-0+0 &
+vym  -l -t -n test $TESTMAP  & #-geometry 768x576-0+0 &
+
 PID=$!
 
 sleep 1
