@@ -2,6 +2,7 @@
 
 #include <QAction>
 #include <QActionGroup>
+#include <QApplication>
 #include <QColorDialog>
 #include <QComboBox>
 #include <QFileDialog>
@@ -34,21 +35,18 @@ extern bool debug;
 ///////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////
 
-TextEditor::TextEditor(QString scope)
+TextEditor::TextEditor()
 {
-    shortcutScope = scope;
-
     statusBar()->hide();    // Hide sizeGrip on default, which comes with statusBar
 
     e = new QTextEdit( this);
     e->setFocus();
     e->setTabStopWidth (20);		// unit is pixel
-    e->setTextColor (Qt::black);
     e->setAutoFillBackground (true);
+    e->installEventFilter(this);
     connect (e, SIGNAL( textChanged() ), this, SLOT( editorChanged() ) );
     setCentralWidget( e );
     statusBar()->showMessage( tr("Ready","Statusbar message"), statusbarTime);
-    setWindowTitle (vymName +" - " +tr ("Text Editor","Text Editor Window caption"));
 
     connect(e, SIGNAL(currentCharFormatChanged(const QTextCharFormat &)),
             this, SLOT(formatChanged(const QTextCharFormat &)));
@@ -65,6 +63,9 @@ TextEditor::TextEditor(QString scope)
     // Various states
     blockChangedSignal=false;
     setInactive();
+
+    editorName = "Text editor";
+    setEditorTitle("");
 }
 
 
@@ -78,18 +79,24 @@ TextEditor::~TextEditor()
 
     QString s;
     if (actionSettingsFonthintDefault->isChecked() )
-	s="fixed";
+	s = "fixed";
     else    
-	s="variable";
+	s = "variable";
     settings.setValue(n + "fonts/fonthintDefault",s );
     settings.setValue(n + "fonts/varFont", varFont.toString() );
     settings.setValue(n + "fonts/fixedFont", fixedFont.toString() );
+
+    settings.setValue(n + "colors/emptyEditor", colorEmptyEditor.name());
+    settings.setValue(n + "colors/filledEditor", colorFilledEditor.name());
+    settings.setValue(n + "colors/inactiveEditor", colorInactiveEditor.name());
+    settings.setValue(n + "colors/font", colorFont.name());
 }
 
-void TextEditor::init (const QString &ename) // FIXME-2 parameter still required?
+void TextEditor::init (const QString &scope) 
 {   
-    QString n=QString("/satellite/%1/").arg(shortcutScope);
-    restoreState (settings.value(n+"state",0).toByteArray());
+    shortcutScope = scope;
+    QString n = QString("/satellite/%1/").arg(shortcutScope);
+    restoreState (settings.value(n + "state", 0).toByteArray());
     filenameHint="";
     fixedFont.fromString (settings.value(
         n + "fonts/fixedFont", "Courier,12,-1,5,48,0,0,0,1,0").toString()
@@ -97,7 +104,7 @@ void TextEditor::init (const QString &ename) // FIXME-2 parameter still required
     varFont.fromString( settings.value(
         n + "fonts/varFont", "DejaVu Sans Mono,12,-1,0,50,0,0,0,0,0").toString()
                         );
-    QString s=settings.value (n+"fonts/fonthintDefault","variable").toString();
+    QString s = settings.value (n + "fonts/fonthintDefault", "variable").toString();
     if (s == "fixed")
     {
         actionSettingsFonthintDefault->setChecked (true);
@@ -107,11 +114,25 @@ void TextEditor::init (const QString &ename) // FIXME-2 parameter still required
         actionSettingsFonthintDefault->setChecked (false);
         e->setCurrentFont (varFont);
     }
-}
+    
+    // Default colors
+    QPixmap pix( 16, 16 );
+    colorEmptyEditor.setNamedColor(   settings.value(n + "colors/emptyEditor", "#969696").toString() );
+    pix.fill( colorEmptyEditor );
+    actionEmptyEditorColor->setIcon(pix);
 
-void TextEditor::reset()
-{
-    e->clear();
+    colorFilledEditor.setNamedColor(  settings.value(n + "colors/filledEditor","#ffffff").toString() );
+    pix.fill( colorFilledEditor );
+    actionFilledEditorColor->setIcon(pix);
+
+    colorInactiveEditor.setNamedColor(settings.value(n + "colors/inactiveEditor","#000000").toString() );
+    pix.fill( colorInactiveEditor );
+    actionInactiveEditorColor->setIcon(pix);
+
+    colorFont.setNamedColor(          settings.value(n + "colors/font","#000000").toString() );
+    e->setTextColor( colorFont );
+    pix.fill( colorFont );
+    actionFontColor->setIcon(pix);
 }
 
 bool TextEditor::isEmpty()
@@ -122,8 +143,29 @@ bool TextEditor::isEmpty()
 	return true;
 }
 
+
+void TextEditor::setEditorTitle(const QString &s)
+{
+    QString h;
+    s.isEmpty() ? h = editorName : h = editorName + ": " + s;
+    editorTitle = h;
+    setWindowTitle (editorTitle);
+}
+
+QString TextEditor::getEditorTitle()
+{
+    return editorTitle;
+}
+
+void TextEditor::setEditorName( const QString &s)
+{
+    editorName = s;
+}
+
 void TextEditor::setFont (const QFont &font)
 {
+    blockChangedSignal = true;
+
     QTextCursor tc=e->textCursor();
     QTextCharFormat format=tc.charFormat();
 
@@ -132,6 +174,8 @@ void TextEditor::setFont (const QFont &font)
     tc.setCharFormat (format);
     tc.clearSelection();
     fontChanged(fixedFont);
+
+    blockChangedSignal = false;
 }
 
 void TextEditor::setFontHint (const QString &fh)
@@ -316,7 +360,7 @@ void TextEditor::setupFileActions()
     actionFilePrint=a;
     
     a = new QAction( QPixmap( ":/edittrash.png"), tr( "&Delete All" ), this);
-    connect( a, SIGNAL( triggered() ), e, SLOT( clear() ) );
+    connect( a, SIGNAL( triggered() ), this, SLOT( reset() ) );
     fileMenu->addAction (a);
     tb->addAction (a);
     actionFileDeleteAll=a;
@@ -396,7 +440,7 @@ void TextEditor::setupFormatActions()
     QAction *a;
 
     a = new QAction( QPixmap(":/formatfixedfont.png"), tr( "&Font hint" ), this );
-    a->setShortcut(Qt::ALT + Qt::Key_I);
+    a->setShortcut(Qt::CTRL + Qt::Key_H);
     a->setCheckable (true);
     a->setChecked (settings.value("/noteeditor/fonts/useFixedByDefault",false).toBool() );
     switchboard.addSwitch( "textToggleFonthint", shortcutScope, a, tag);
@@ -406,9 +450,9 @@ void TextEditor::setupFormatActions()
     actionFormatUseFixedFont=a;
 
     // Original icon: ./share/icons/oxygen/22x22/actions/format-text-color.png
-    a = new QAction( QPixmap(":/formatrichtext.png"), tr( "&Richtext" ), this );
-    a->setShortcut (Qt::ALT + Qt::Key_R);
-    a->setShortcutContext (Qt::WidgetWithChildrenShortcut);
+    a = new QAction( QPixmap(":/formatrichtext.png"), tr( "&Richtext" ), this);
+    a->setShortcut ( Qt::CTRL + Qt::Key_R);
+//    a->setShortcutContext (Qt::WidgetShortcut);
     a->setCheckable (true);
     switchboard.addSwitch( "textToggleRichText", shortcutScope, a, tag);
     connect( a, SIGNAL( triggered() ), this, SLOT( toggleRichText() ) );
@@ -557,6 +601,28 @@ void TextEditor::setupSettingsActions()
     // set state later in constructor...
     settingsMenu->addAction (a);
     actionSettingsFonthintDefault=a;
+
+    settingsMenu->addSeparator();
+
+    a = new QAction( tr( "Set empty editor background color", "TextEditor") + "...", this  );
+    settingsMenu->addAction (a);
+    connect( a, SIGNAL( triggered() ), this, SLOT( setEmptyEditorColor() ) );
+    actionEmptyEditorColor = a;
+
+    a = new QAction( tr( "Set filled editor background color", "TextEditor") + "...", this  );
+    settingsMenu->addAction (a);
+    connect( a, SIGNAL( triggered() ), this, SLOT( setFilledEditorColor() ) );
+    actionFilledEditorColor = a;
+
+    a = new QAction( tr( "Set inactive editor background color", "TextEditor") + "...", this  );
+    settingsMenu->addAction (a);
+    connect( a, SIGNAL( triggered() ), this, SLOT( setInactiveEditorColor() ) );
+    actionInactiveEditorColor = a;
+
+    a = new QAction( tr( "Set default font color", "TextEditor") + "...", this  );
+    settingsMenu->addAction (a);
+    connect( a, SIGNAL( triggered() ), this, SLOT( setFontColor() ) );
+    actionFontColor = a;
 }
 
 void TextEditor::textLoad()
@@ -613,12 +679,23 @@ void TextEditor::closeEvent( QCloseEvent* ce )
     return;
 }
 
-void TextEditor::keyPressEvent(QKeyEvent* e)
+bool TextEditor::eventFilter( QObject *obj, QEvent *ev)
 {
-    if (e->key() == Qt::Key_Escape)
-        emit( focusReleased());
-    else
-        QMainWindow::keyPressEvent(e);
+    if (obj == e ) {
+        if (ev->type() == QEvent::KeyPress) {
+            QKeyEvent *keyEvent = static_cast<QKeyEvent*>(ev);
+            if(keyEvent == QKeySequence::Paste) 
+            {
+                // switch editor mode to match clipboard content before pasting
+                const QClipboard *clipboard = QApplication::clipboard();
+                const QMimeData *mimeData = clipboard->mimeData();
+
+                if (mimeData->hasHtml()) setRichTextMode(true);
+            } 
+        }
+    }
+    // pass the event on to the parent class
+    return QMainWindow::eventFilter(obj, ev);
 }
 
 void TextEditor::editorChanged()
@@ -694,6 +771,13 @@ void TextEditor::editCopyAll()
     e->copy();
 }
 
+void TextEditor::reset()
+{
+    e->selectAll();
+    e->textCursor().deleteChar();
+    e->setTextColor( colorFont );
+}
+
 void TextEditor::textSaveAs()	
 {
     QString caption=tr ("Export Note to single file");
@@ -757,6 +841,7 @@ void TextEditor::textSave()
     }
 
     QTextStream t( &f );
+    t.setCodec("UTF-8");
     t << text;
     f.close();
 
@@ -842,22 +927,32 @@ void TextEditor::toggleFonthint()
         e->setCurrentFont (fixedFont);
         setFont (fixedFont);
     }
+    emit( textHasChanged() );
+}
+
+void TextEditor::setRichTextMode(bool b)
+{
+    if (b)
+    {
+        e->setHtml (e->toHtml());
+        actionFormatUseFixedFont->setEnabled(false);
+        actionFormatRichText->setChecked(true);
+    } else
+    {
+        e->setPlainText (e->toPlainText());
+        actionFormatUseFixedFont->setEnabled(true);
+        actionFormatRichText->setChecked(false);
+    }
+    updateActions();
+    emit( textHasChanged() );
 }
 
 void TextEditor::toggleRichText()
 {
-    if (!actionFormatRichText->isChecked() )
-    {
-        e->setPlainText (e->toPlainText());
-        actionFormatUseFixedFont->setEnabled(true);
-    }
+    if (actionFormatRichText->isChecked() )
+        setRichTextMode( true );
     else
-    {
-        e->setHtml (e->toHtml());
-        actionFormatUseFixedFont->setEnabled(false);
-    }
-    updateActions();
-    emit( textHasChanged() );
+        setRichTextMode( false );
 }
 
 void TextEditor::setFixedFont()
@@ -908,16 +1003,16 @@ void TextEditor::textColor()
     QColor col = QColorDialog::getColor( e->textColor(), this );
     if ( !col.isValid() ) return;
     e->setTextColor( col );
+    /*
     QPixmap pix( 16, 16 );
-    pix.fill( Qt::black );
+    pix.fill( col );
     actionTextColor->setIcon( pix );
+    */
 }
 
-void TextEditor::textAlign( QAction *a )  //FIXME-2 center only centers first line
+void TextEditor::textAlign( QAction *a ) 
 {
-    QTextCursor c=e->textCursor();
-    c.setPosition (3,QTextCursor::MoveAnchor);
-    e->setTextCursor (c);
+    QTextCursor c = e->textCursor();
 
     if ( a == actionAlignLeft )
         e->setAlignment( Qt::AlignLeft );
@@ -1057,17 +1152,56 @@ void TextEditor::updateActions()
 void TextEditor::setState (EditorState s)
 {
     
-    QPalette p=palette();
+    QPalette p = palette();
     QColor c;
     switch (s)
     {
-        case emptyEditor:    c=QColor (150,150,150); break;
-        case filledEditor:   c=QColor (255,255,255); break;
-        case inactiveEditor: c=QColor (0,0,0);
+        case emptyEditor:    c = colorEmptyEditor; break;
+        case filledEditor:   c = colorFilledEditor; break; 
+        case inactiveEditor: c = colorInactiveEditor;
     }
     p.setColor(QPalette::Active, static_cast<QPalette::ColorRole>(9), c);
     p.setColor(QPalette::Inactive, static_cast<QPalette::ColorRole>(9), c);
     e->setPalette(p);
 }
 
+void TextEditor::setEmptyEditorColor()
+{
+    QColor col = QColorDialog::getColor( colorEmptyEditor, NULL);
+    if ( !col.isValid() ) return;
+    colorEmptyEditor = col;
+    QPixmap pix( 16, 16 );
+    pix.fill( colorEmptyEditor );
+    actionEmptyEditorColor->setIcon(pix);
+}
+
+void TextEditor::setInactiveEditorColor()
+{
+    QColor col = QColorDialog::getColor( colorInactiveEditor, NULL);
+    if ( !col.isValid() ) return;
+    colorInactiveEditor = col;
+    QPixmap pix( 16, 16 );
+    pix.fill( colorInactiveEditor );
+    actionInactiveEditorColor->setIcon(pix);
+}
+
+void TextEditor::setFilledEditorColor()
+{
+    QColor col = QColorDialog::getColor( colorFilledEditor, NULL);
+    if ( !col.isValid() ) return;
+    colorFilledEditor = col;
+    QPixmap pix( 16, 16 );
+    pix.fill( colorFilledEditor );
+    actionFilledEditorColor->setIcon(pix);
+}
+
+void TextEditor::setFontColor()
+{
+    QColor col = QColorDialog::getColor( colorFont, NULL);
+    if ( !col.isValid() ) return;
+    colorFont = col;
+    QPixmap pix( 16, 16 );
+    pix.fill( colorFont );
+    actionFontColor->setIcon(pix);
+}
 
