@@ -11,15 +11,17 @@ class QComboBox;
 
 enum EditorState {inactiveEditor,emptyEditor,filledEditor};
 
-class TextEditor :public QMainWindow
+class TextEditor : public QMainWindow
 {    Q_OBJECT
 public:
-    TextEditor(QString scope);
+    TextEditor();
     ~TextEditor();
 
     void init(const QString &ename);
-    void reset();
     bool isEmpty();
+    void setEditorName( const QString & );
+    void setEditorTitle(const QString &);
+    QString getEditorTitle();
     void setFont (const QFont &);
     void setFontHint(const QString&);
     QString getFontHint();
@@ -43,7 +45,7 @@ protected:
     void setupFormatActions();
     void setupSettingsActions();
     void closeEvent( QCloseEvent* );
-    void keyPressEvent(QKeyEvent* );
+    bool eventFilter(QObject *obj, QEvent *ev);
 
 public slots:
     void editorChanged();	    // received when text() changed
@@ -53,11 +55,11 @@ public slots:
     void setVymText(const VymText &vt);
     void setInactive();		    // Nothing can be entered
     void editCopyAll();
+    void reset();
 
 signals:
     void textHasChanged();
     void windowClosed();
-    void focusReleased();
     void fontFamilyHasChanged();
     void fontSizeHasChanged();
     
@@ -69,6 +71,7 @@ private slots:
     void textPrint();
     void textEditUndo();
     void toggleFonthint();
+    void setRichTextMode(bool b);
     void toggleRichText();
     void setFixedFont();
     void setVarFont();
@@ -87,11 +90,17 @@ private slots:
     void verticalAlignmentChanged(QTextCharFormat::VerticalAlignment);
     void updateActions();
     void setState (EditorState);
+    void setEmptyEditorColor();
+    void setInactiveEditorColor();
+    void setFilledEditorColor();
+    void setFontColor();
 
 protected:
     QString shortcutScope;  // used for settings and shortcut scopes
     QTextEdit *e;
     QPoint lastPos;	    // save last position of window
+    QString editorName;     // Name of editor, e.g. note editor, heading editor, ...
+    QString editorTitle;    // window title: Editor name + selected branch
     QString filename;
     QString filenameHint;
 
@@ -101,6 +110,11 @@ protected:
     EditorState state;
     bool blockChangedSignal;
 
+    QColor colorEmptyEditor;
+    QColor colorFilledEditor;
+    QColor colorInactiveEditor;
+    QColor colorFont;
+
     QFont varFont;
     QFont fixedFont;
     QComboBox *comboFont, *comboSize;
@@ -124,7 +138,11 @@ protected:
     *actionFormatRichText,
     *actionSettingsVarFont,
     *actionSettingsFixedFont,
-    *actionSettingsFonthintDefault;
+    *actionSettingsFonthintDefault,
+    *actionEmptyEditorColor,
+    *actionFilledEditorColor,
+    *actionInactiveEditorColor,
+    *actionFontColor;
 
     QAction *actionTextBold,
     *actionTextUnderline,
