@@ -13,10 +13,10 @@ class TreeEditor : public QTreeView {
     Q_OBJECT
 
 public:
-    TreeEditor(VymModel *m);
+    TreeEditor(VymModel *m=NULL);
     ~TreeEditor();
+    void init();
     QModelIndex getSelectedIndex();
-
 private slots:
     void cursorUp();
     void cursorDown();
