@@ -146,7 +146,7 @@ void TreeItem::appendChild(TreeItem *item)
 	childItems.append(item);
 	branchCounter++;
 
-	// Set correct type	//FIXME-5 DUP in constr branchitem
+	// Set correct type	
 	if (this==rootItem)
 	    item->setType(MapCenter);
 	else
@@ -298,7 +298,7 @@ void TreeItem::setType(const Type t)
 
 TreeItem::Type TreeItem::getType()
 {
-    if (type==Branch && depth()==0) return MapCenter;	//FIXME-5 should not be necesssary
+    if (type==Branch && depth()==0) return MapCenter;	// should not be necesssary
     return type;
 }
 
@@ -367,6 +367,26 @@ QString TreeItem::getHeadingPlain() const
     return heading.getTextASCII().trimmed();
 }
 
+QString TreeItem::getHeadingPlainWithParents(uint numberOfParents = 0) 
+{
+    QString s = getHeadingPlain();
+    if (numberOfParents > 0) 
+    {
+        TreeItem *ti = this;
+        int l = numberOfParents;
+        while ( l > 0 && ti->depth() > 0 )
+        {
+            ti = ti->parent();
+            if (ti)
+                s = ti->getHeadingPlain() + " -> " + s;
+            else
+                l = 0;
+            l--;
+        }
+    }
+    return s;
+}
+
 QString TreeItem::getHeadingDepth () // Indent by depth for debugging
 {
     QString ds;
@@ -520,11 +540,6 @@ QString TreeItem::getNoteASCII()
     return note.getTextASCII();
 }
 
-QString TreeItem::getNoteOpenDoc()
-{
-    return note.getTextOpenDoc();
-}
-
 void TreeItem::activateStandardFlag (const QString &name)
 {
     standardFlags.activate (name);
@@ -712,7 +727,7 @@ ImageItem* TreeItem::getImageNum (const int &n)
 	return NULL;
 }
 
-FloatImageObj* TreeItem::getImageObjNum (const int &n)	// FIXME-5 what about SVGs later?
+FloatImageObj* TreeItem::getImageObjNum (const int &n)	
 {
     if (imageCounter>0 )
 	return (FloatImageObj*)(getImageNum(n)->getLMO());
