@@ -121,85 +121,142 @@ int TreeModel::columnCount(const QModelIndex &parent) const
     return c;
 }
 
-BranchItem* TreeModel::nextBranch (BranchItem* &current, BranchItem* &previous, bool deepLevelsFirst, BranchItem *start)    
+void TreeModel::nextBranch (BranchItem* &current, BranchItem* &previous, bool deepLevelsFirst, BranchItem *start)    
 {
-    // Walk through map beginning at current with previous==0
-    // Start at root, if current==NULL
-    if (!current) current=(BranchItem*)rootItem;
-
-    // Are we just beginning to walk the map?
-    if (!previous)
-    {
-	if (!start) start=current;
-	previous=current;
-	current=current->getFirstBranch();
-	return current;
-    }
     if (deepLevelsFirst)
     {
-	// Going up or down (deeper)?
+        // Walk through map beginning at current with previous==0
+        // Start at root, if current==NULL
+        if (!current) 
+        {
+            if (start)
+            {
+                current=start;
+                previous=current->parentBranch();
+            } else
+            {
+                previous=(BranchItem*)rootItem;
+                current = previous->getFirstBranch();
+                return;
+            }
+        }
+        
+        // Walk the tree by always turning "left" 
+        // and returning an element when going up
+        if (current == previous)
+        {
+            // Had leaf before, go up again.
+            if (start && start == current)
+            {
+                current=NULL;
+                return;
+            }
+            current = current->parentBranch();
+            if (!current) return;
+            return nextBranch(current, previous, deepLevelsFirst, start);
+        }
+
 	if (current->depth() > previous->depth() )
 	{   
-	    // Coming from above
-	    // Trying  to go down deeper
+	    // Coming from above, try to go deeper
 	    if (current->branchCount() >0 )
 	    {
+                // Turn "left" and go deeper
 		previous=current;
 		current=current->getFirstBranch();
-		return current;
-	    }	
-	    // turn around and go up again
-	    BranchItem *bi=current;
-	    current=previous;
-	    previous=bi;
-	}   
-
-	// Coming from below
-	// Trying to go down again to siblings
-
-	BranchItem *sibling=current->getBranchNum (previous->num()+1);
-
-	if (sibling)
-	{   
-	    // Found sibling of previous, go there
-	    previous=current;
-	    current=sibling;
-	    return current;
-	} 
-
-	// If we only needed to go through subtree, we are done now
-	if (start==current) return NULL;
-
-	// Go up and try to find siblings of current
-	previous=current;
-	current=(BranchItem*)current->parent();
-
-	// Check if we still can go somewhere
-	if (!current) return current;
-	
-	while (current && current->depth() < previous->depth() )
-	    current=nextBranch (current,previous,true,start);
-	    
-	return current;
+                return nextBranch (current, previous, deepLevelsFirst);
+	    } else	
+            {
+                // turn around and go up again
+                previous=current;
+                return;
+            }
+	}   else
+        {
+            // Coming from below, try to go down again to siblings
 
+            BranchItem *sibling=current->getBranchNum (previous->num()+1);
+            if (sibling)
+            {   
+                // Found sibling of previous, go there
+                previous=current;
+                current=sibling;
+                return nextBranch (current, previous, deepLevelsFirst, start);
+            } else
+            {
+                // and go further up
+                if (current == rootItem) current = NULL;
+                previous = current;
+                return;
+            }
+        }
     } else
     {
-	// Try to find sibling with same depth
-	BranchItem *sibling=current->parent()->getBranchNum (current->num()+1);
-	if (sibling)
-	{   
-	    // Found sibling of previous, go there
-	    previous=current;
-	    current=sibling;
-	    return current;
-	}  else
-	{   
-	    // Try to find next branch with same depth or greater
-	    
+        // Walk through map beginning at current with previous==0
+        // Start at root, if current==NULL
+        if (!current) 
+        {
+            if (start) 
+            {
+                current=start;    
+                previous=(BranchItem*)(start->parent() );
+                return;
+            } else
+            {
+                previous=(BranchItem*)rootItem;
+                current = previous->getFirstBranch();
+                return;
+            }
+        }
 
-	    current=NULL;
-	    return current;
-	}
+
+	if (current->depth() > previous->depth() )
+	{   
+            // Going deeper 
+	    if (current->branchCount() >0 )
+	    {
+                // Turn "left" and go deeper
+		previous=current;
+		current=current->getFirstBranch();
+                return;
+	    } else	
+            {
+                // turn around and go up again
+                previous=current;
+                nextBranch (current, previous, deepLevelsFirst, start);
+                return;
+            }
+        } else
+        {
+            if (start && previous == start)
+            {
+                current=NULL;
+                return;
+            }
+
+            BranchItem *sibling=current->getBranchNum (previous->num()+1);
+            if (sibling)
+            {   
+                // Found sibling of previous, go there
+                previous=current;
+                current=sibling;
+                return; 
+            } else
+            {
+                // no sibling, go further up left
+                previous=current;
+                current = current->parentBranch();
+                if (!current)
+                {
+                    current = NULL;
+                    return;
+                } else
+                {
+                    nextBranch (current, previous, deepLevelsFirst, start);
+                }
+            }
+            return;
+        }
     }
 }
 
