@@ -17,6 +17,7 @@
 #include "parser.h"
 #include "treeitem.h"
 #include "treemodel.h"
+#include "vymlock.h"
 
 class AttributeItem;
 class BranchItem;
@@ -66,7 +67,6 @@ private:
 
 public:
     bool isRepositionBlocked();	    //!< While load or undo there is no need to update graphicsview
-
     void updateActions();	    //!< Update buttons in mainwindow
 
 
@@ -160,6 +160,15 @@ private:
 public:	
     void importDir();
 
+    bool tryVymLock();
+    bool renameMap( const QString &newPath); //! Rename map and change lockfile
+    void setReadOnly( bool b );
+    bool isReadOnly();
+
+private:
+    VymLock  vymLock;       //! Handle lockfiles and related information
+    bool readonly;          //! if map is locked, it can be opened readonly
+
 private slots:
     void autosave ();
     void fileChanged();
@@ -174,7 +183,7 @@ private:
 
     QString histPath;		//!< Path to history file
     SimpleSettings undoSet;	//!< undo/redo commands, saved in histPath
-    int stepsTotal;		//!< total number of steps (undos+redos) 
+    int stepsTotal;		//!< total number of steps (undos+redos)
     int curStep;		//!< Current step in history (ring buffer)
     int curClipboard;		//!< number of history step, which is the current clipboard
     int redosAvail;		//!< Available number of redo steps
