@@ -17,12 +17,14 @@ public:
     enum XLinkState {undefinedXLink,initXLink,activeXLink,deleteXLink};	
 
     XLinkItem (const QList<QVariant> &data, TreeItem *parent=NULL);
-    virtual ~XLinkItem ();
-    virtual void init ();
+    ~XLinkItem ();
+    void init ();
+    void clear ();
     void setLink (Link*);
     Link* getLink ();
     void updateXLink();
     MapObj* getMO();
+    void setSelection();
     BranchItem* getPartnerBranch ();
 
 
