@@ -22,26 +22,31 @@ QString parseBaseHandler::parseHREF(QString href)
 bool parseBaseHandler::fatalError( const QXmlParseException& exception ) 
 {
     errorProt += QString( "Fatal parsing error: %1 in line %2, column %3\n")
-    .arg( exception.message() )
-    .arg( exception.lineNumber() )
-    .arg( exception.columnNumber() );
+        .arg( exception.message() )
+        .arg( exception.lineNumber() )
+        .arg( exception.columnNumber() );
     // Try to read the bogus line
-    errorProt+=QString("File is: %1\n").arg(inputFile);
-    QString s;
-    if (loadStringFromDisk (inputFile,s))
-    {
-	QStringList sl=s.split ("\n");
-	int i=1;
-	QStringList::Iterator it = sl.begin();
-	while (i<exception.lineNumber())
-	{
-	    it++;
-	    i++;
-	}
-	s=*it;
-	s.insert (exception.columnNumber()-1,"<ERROR>");
-	errorProt+=s;
+    errorProt += QString("File is: %1\n").arg(inputFile);
+    if (!inputFile.isEmpty() )
+    {   // Input was from file
+        if (!loadStringFromDisk (inputFile, inputString))
+        {
+            qWarning()<<"parseBaseHandler::fatalError Couldn't read from "<<inputFile;
+            return QXmlDefaultHandler::fatalError( exception );
+        }
     }
+    QString s;
+    QStringList sl = inputString.split ("\n");
+    int i = 1;
+    QStringList::Iterator it = sl.begin();
+    while (i < exception.lineNumber())
+    {
+        it++;
+        i++;
+    }
+    s =*it;
+    s.insert (exception.columnNumber()-1,"<ERROR>");
+    errorProt += s;
     return QXmlDefaultHandler::fatalError( exception );
 }
 
@@ -55,9 +60,14 @@ void parseBaseHandler::setTmpDir (QString tp)
     tmpDir=tp;
 }
 
-void parseBaseHandler::setInputFile (QString f)
+void parseBaseHandler::setInputFile (const QString &s)
 {
-    inputFile=f;
+    inputFile = s;
+}
+
+void parseBaseHandler::setInputString ( const QString &s)
+{
+    inputString = s;
 }
 
 void parseBaseHandler::setLoadMode (const LoadMode &lm, int p)
