@@ -25,7 +25,7 @@ extern QString vymVersion;
 parseVYMHandler::parseVYMHandler()
 {
     // Default is to load everything
-    contentFilter = 0x0000; //FIXME-4 use filters for all content types below
+    contentFilter = 0x0000; // TODO  use filters for all content types below
 }
 
 void parseVYMHandler::setContentFilter (const int &c)
@@ -45,18 +45,6 @@ bool parseVYMHandler::startDocument()
     return true;
 }
 
-bool parseVYMHandler::startCDATA()
-{
-    qDebug()<<"xml-VYM: Now reading CDATA"; //FIXME-3 testing, not called?
-    return true;
-}
-
-bool parseVYMHandler::endCDATA()
-{
-    qDebug()<<"xml-VYM: Finished reading CDATA";//FIXME-3 testing, not callednipp
-    return true;
-}
-
 bool parseVYMHandler::startElement  ( const QString&, const QString&,
                     const QString& eName, const QXmlAttributes& atts ) 
 {
@@ -579,7 +567,7 @@ bool parseVYMHandler::readBranchAttr (const QXmlAttributes& a)
     return true;    
 }
 
-bool parseVYMHandler::readFrameAttr (const QXmlAttributes& a)        // FIXME-4 does not work if there is no lmo for treeitem
+bool parseVYMHandler::readFrameAttr (const QXmlAttributes& a)       
 {
     if (lastMI)
     {
@@ -707,6 +695,7 @@ bool parseVYMHandler::readNoteAttr (const QXmlAttributes& a)
             return false;
         }   
         QTextStream stream( &file );
+        stream.setCodec("UTF-8");
         QString lines;
         while ( !stream.atEnd() ) {
             lines += stream.readLine()+"\n"; 
